@@ -38,6 +38,8 @@ describe 'murano' do
       it { is_expected.to contain_murano_config('engine/use_trusts').with_value('<SERVICE DEFAULT>') }
 
       it { is_expected.to contain_murano_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_murano_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_murano_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_murano_config('oslo_messaging_rabbit/rabbit_userid').with_value('guest') }
       it { is_expected.to contain_murano_config('oslo_messaging_rabbit/rabbit_password').with_value('guest') }
       it { is_expected.to contain_murano_config('oslo_messaging_rabbit/rabbit_hosts').with_value('<SERVICE DEFAULT>') }
@@ -78,6 +80,8 @@ describe 'murano' do
         :package_ensure          => 'latest',
         :notification_driver     => 'messagingv1',
         :default_transport_url   => 'rabbit://user:pass@host:1234/virt',
+        :rpc_response_timeout    => '120',
+        :control_exchange        => 'murano',
         :rabbit_os_host          => '10.255.0.1',
         :rabbit_os_port          => '5673',
         :rabbit_os_user          => 'os',
@@ -131,6 +135,8 @@ describe 'murano' do
       it { is_expected.to contain_murano_config('engine/use_trusts').with_value(true) }
 
       it { is_expected.to contain_murano_config('DEFAULT/transport_url').with_value('rabbit://user:pass@host:1234/virt') }
+      it { is_expected.to contain_murano_config('DEFAULT/rpc_response_timeout').with_value('120') }
+      it { is_expected.to contain_murano_config('DEFAULT/control_exchange').with_value('murano') }
       it { is_expected.to contain_murano_config('oslo_messaging_rabbit/rabbit_userid').with_value('os') }
       it { is_expected.to contain_murano_config('oslo_messaging_rabbit/rabbit_password').with_value('ossecrete') }
       it { is_expected.to contain_murano_config('oslo_messaging_rabbit/rabbit_host').with_value('10.255.0.1') }
